@@ -13,7 +13,7 @@
 ##############################################################################
 """User Preferences Browser Views
 
-$Id: browser.py 85701 2008-04-24 18:40:28Z lgs $
+$Id: browser.py 95496 2009-01-29 18:48:33Z thefunny42 $
 """
 __docformat__ = 'restructuredtext'
 
@@ -21,13 +21,13 @@ import re
 import zope.component
 import zope.interface
 import zope.schema
-from zope.security.proxy import removeSecurityProxy
+from zope.container.interfaces import IObjectFindFilter
 from zope.i18n import translate
 from zope.i18nmessageid import Message
+from zope.security.proxy import removeSecurityProxy
 from zope.traversing.api import getParent, getRoot
 
 from zope.app.basicskin.standardmacros import StandardMacros
-from zope.app.container.interfaces import IObjectFindFilter
 from zope.app.form.browser.editview import EditView
 from zope.app.pagetemplate.simpleviewclass import simple
 from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
